@@ -52,7 +52,8 @@ interoptopus::inventory!(
         functions::complex_args_1,
         functions::complex_args_2,
         functions::callback,
-        functions::generic_1,
+        functions::generic_1a,
+        functions::generic_1b,
         functions::generic_2,
         functions::generic_3,
         functions::generic_4,
